# heat_stroke
This program uses machine learning to predict the number of heat stroke patients using data on the number of heat stroke carriers in Japan and meteorological data.


# How to install heat_stroke
$ pip install heat_stroke

# How to run heat_stroke

$ heat_stroke




